==> snobol4-1.5.txz: usr/local/lib/snobol4/1.5/include/config.h <==
/*
 * generated Mon Oct 7 07:06:32 UTC 2013
 * on 100amd64-default-job-01 (FreeBSD)
 * by $Id: configure,v 1.216 2013/10/01 15:31:14 phil Exp $
 */

#define CONFIG_OPTIONS "--prefix=/usr/local --snolibdir=/usr/local/lib/snobol4"
#define CONFIG_HOST "100amd64-default-job-01"
#define CONFIG_DATE "Mon Oct 7 07:06:32 UTC 2013"
#define DIR_SEP "/"
#define PATH_SEP ":"
#define PML_SERV
#define PML_RANDOM
#define HAVE_BUILD_VARS
#define NO_BITFIELDS
#define SIZLIM (~(VFLD_T)0)
#define REAL_T double
#define REALST_FORMAT "%.15lg"
#define HAVE_STDLIB_H
#define HAVE_UNISTD_H
#define GETRUSAGE_BUG
#define HAVE_STRINGS_H
#define HAVE_STRING_H
#define BINDRESVPORT_IN_RPC_H
#define HAVE_SOCKADDR_IN6
#define SOCKLEN_T socklen_t
/* vfork() in unistd.h */
#define HAVE_FORKPTY
#define HAVE_LIBUTIL_H
#define HAVE_PATHS_H
#define TRY_UNDERSCORE
#define SNOLIB_BASE "/usr/local/lib/snobol4"
#define SNOLIB_DIR "/usr/local/lib/snobol4/1.5/lib"
#define INCLUDE_DIR "/usr/local/lib/snobol4/1.5/include"
/* NOTE: SNOLIB_FILE in config.m4 too! */
#define SNOLIB_FILE "snolib.so"
#define HAVE_FSEEKO
#define HAVE_GETTIMEOFDAY
#define HAVE_TM_GMTOFF
#define HAVE_SLEEP
#define HAVE_STRPTIME
#define PML_TIME
/* Shared Object Libraries (in config.m4 too) */
#define SO_EXT ".so"
#define SO_CFLAGS "-fpic"
#define SO_LD "cc"
#define SO_LDFLAGS "-shared"
/* Dynamicly Loaded Extensions (in config.m4 too) */
#define DL_EXT ".so"
#define DL_CFLAGS "-fpic"
#define DL_LD "cc"
#define DL_LDFLAGS "-shared"
#define HAVE_NDBM_H
#define PML_NDBM
#define PML_READLINE
#define COMPILER_READLINE
/* from CFLAGS: */

/* if the file local-defines existed it would have been incorporated here */

==> snobol4-1.5_1.txz: usr/local/lib/snobol4/1.5/include/config.h <==
/*
 * generated Wed Sep 17 08:42:39 UTC 2014
 * on 91amd64-default-job-01 (FreeBSD)
 * by $Id: configure,v 1.216 2013/10/01 15:31:14 phil Exp $
 */

#define CONFIG_OPTIONS "--prefix=/usr/local --snolibdir=/usr/local/lib/snobol4"
#define CONFIG_HOST "91amd64-default-job-01"
#define CONFIG_DATE "Wed Sep 17 08:42:39 UTC 2014"
#define DIR_SEP "/"
#define PATH_SEP ":"
#define PML_SERV
#define PML_RANDOM
#define HAVE_BUILD_VARS
#define NO_BITFIELDS
#define SIZLIM (~(VFLD_T)0)
#define REAL_T double
#define REALST_FORMAT "%.15lg"
#define HAVE_STDLIB_H
#define HAVE_UNISTD_H
#define GETRUSAGE_BUG
#define HAVE_STRINGS_H
#define HAVE_STRING_H
#define BINDRESVPORT_IN_RPC_H
#define HAVE_SOCKADDR_IN6
#define SOCKLEN_T socklen_t
/* vfork() in unistd.h */
#define HAVE_FORKPTY
#define HAVE_LIBUTIL_H
#define HAVE_PATHS_H
#define TRY_UNDERSCORE
#define SNOLIB_BASE "/usr/local/lib/snobol4"
#define SNOLIB_DIR "/usr/local/lib/snobol4/1.5/lib"
#define INCLUDE_DIR "/usr/local/lib/snobol4/1.5/include"
/* NOTE: SNOLIB_FILE in config.m4 too! */
#define SNOLIB_FILE "snolib.so"
#define HAVE_FSEEKO
#define HAVE_GETTIMEOFDAY
#define HAVE_TM_GMTOFF
#define HAVE_SLEEP
#define HAVE_STRPTIME
#define PML_TIME
/* Shared Object Libraries (in config.m4 too) */
#define SO_EXT ".so"
#define SO_CFLAGS "-fpic"
#define SO_LD "cc"
#define SO_LDFLAGS "-shared"
/* Dynamicly Loaded Extensions (in config.m4 too) */
#define DL_EXT ".so"
#define DL_CFLAGS "-fpic"
#define DL_LD "cc"
#define DL_LDFLAGS "-shared"
#define HAVE_NDBM_H
#define PML_NDBM
#define PML_READLINE
#define COMPILER_READLINE
/* from CFLAGS: */

/* if the file local-defines existed it would have been incorporated here */
